(find-user-id-via-email this email)Returns user-name string or nil.
Returns user-name string or nil.
(get-user this user-name)Returns user map or nil. user-name is a string.
Returns user map or nil. user-name is a string.
(get-user-roles this user-name)Returns role set or nil if user not found.
Returns role set or nil if user not found.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |